aboutsummaryrefslogtreecommitdiff
path: root/src/spans.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/spans.rs')
-rw-r--r--src/spans.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/spans.rs b/src/spans.rs
index ee63dd3..4333bd1 100644
--- a/src/spans.rs
+++ b/src/spans.rs
@@ -7,7 +7,7 @@
//! * one for [`Range<usize>`] for when you do want to track spans
//!
//! To use the latter your reader however has to implement [`GetPos`].
//! You can easily use any existing reader by wrapping it in the [`PosTracker`] struct
//! which implements the [`GetPos`] trait and takes care of tracking the current position.
use std::ops::Range;
@@ -21,14 +21,14 @@ pub trait GetPos {
}
/// Wraps a [`Reader`] so that it implements [`GetPos`].
-pub struct PosTracker<R> {
+pub struct PosTrackingReader<R> {
/// The wrapped reader.
pub reader: R,
/// The current position.
pub position: usize,
}
-impl<R> GetPos for PosTracker<R> {
+impl<R> GetPos for PosTrackingReader<R> {
fn get_pos(&self) -> usize {
self.position
}
@@ -68,7 +68,7 @@ impl<P: GetPos> Span<P> for Range<usize> {
}
}
-impl<R: Reader> Reader for PosTracker<R> {
+impl<R: Reader> Reader for PosTrackingReader<R> {
type Error = R::Error;
fn read_char(&mut self) -> Result<Option<char>, Self::Error> {
@@ -7,7 +7,7 @@
//!
//! To use the latter your reader however has to implement [`GetPos`].
-//! You can easily use any existing reader by wrapping it in the [`PosTracker`] struct
+//! You can easily use any existing reader by wrapping it in the [`PosTrackingReader`] struct
//! which implements the [`GetPos`] trait and takes care of tracking the current position.
use std::ops::Range;